@@ -151,7 +151,7 @@ class MessageTypes(object):
         # Default motorcortex messages are loaded from the library folder.
         # They could be replaced by load command if needed
         path = os.path.dirname(motorcortex.motorcortex_pb2.__file__)
-        self.load([{'proto': motorcortex.motorcortex_pb2, 'hash': path + '/motorcortex_hash.json'}])
+        self.load([{'proto': motorcortex.motorcortex_pb2, 'hash': os.sep.join([path, 'motorcortex_hash.json'])}])
 
     def motorcortex(self):
         """Returns default motorcortex messages, provided with the package.
