@@ -43,7 +43,7 @@ class Subscribe:
                 bool: True - if connected, False otherwise
         """
 
-        conn_timeout_ms, recv_timeout_ms, certificate = Request.parse(**kwargs)
+        conn_timeout_ms, recv_timeout_ms, certificate, state_update = Request.parse(**kwargs)
         if recv_timeout_ms == 0:
             recv_timeout_ms = 500
 
